DebArchitecture

Enum DebArchitecture 

pub enum DebArchitecture {
Show 24 variants All, Alpha, Armel, Armhf, Arm64, Hppa, I386, Amd64, Ia64, M68k, Mips, Mipsel, Mips64el, PowerPC, Ppc64, Ppc64el, Riscv64, S390x, Sh4, Sparc4, X32, HurdI386, KFreebsdI386, KFreebsdAmd64,
}
Variants



All

For architecture independent packages, such as interpreted software or configuration files.



Alpha



Armel

Arm versions 5T and 6



Armhf

Armv7 (hard float)



Arm64

Armv8



Hppa



I386

32-bit x86



Amd64

64-bit x86_64



Ia64



M68k



Mips



Mipsel

Little-endian 32-bit



Mips64el

Little-endian 64-bit



PowerPC



Ppc64



Ppc64el



Riscv64



S390x



Sh4



Sparc4



X32



HurdI386

32-bit x86 for GNU/Hurd



KFreebsdI386

32-bit x86 for FreeBSD



KFreebsdAmd64

64-bit x86_64 for FreeBSD

Implementations

Source

impl DebArchitecture

pub fn as_str(&self) -> &str

Converts DebArchitecture to &str.

pub fn from(input: &str) -> Result<Self>

Converts &str to DebArchitecture.

This function will return an error if the given string doesn’t match any architecture name.